Enum webp_animation::Error[][src]

pub enum Error {
Show variants OptionsInitFailed, DecodeFailed, DecoderGetInfoFailed, TooLargeCanvas(u32u32usize), EncoderCreateFailed, BufferSizeFailed(usizeusize), PictureImportFailed, EncoderAddFailed, WrongColorMode(ColorModeColorMode), TimestampMustBeHigherThanPrevious(i32i32), TimestampMustBeEqualOrHigherThanPrevious(i32i32), EncoderAssmebleFailed, DimensionsMustbePositive, NoFramesAdded, ZeroSizeBuffer, InvalidEncodingConfig,
}

Error type produced by webp_animation code

Variants

OptionsInitFailed

Initializing webp options failed, internal (memory allocation?) failure

DecodeFailed

Decoder init failed, input contains wrong bytes

DecoderGetInfoFailed

Decoder could not get metadata of webp stream. Corrupt data?

TooLargeCanvas(u32u32usize)

Webp stream contains too large canvas. For now, size is limited to 3840 * 2160 pixels See MAX_CANVAS_SIZE variable from code

EncoderCreateFailed

Encoder create failed. Wrong options combination?

BufferSizeFailed(usizeusize)

Data input buffer size did not match encoder metadata (width * height * 4)

PictureImportFailed

Raw data could not be converted into webp frame by underlying libwebp library

EncoderAddFailed

Frame could not be added to webp stream by underlying libwebp library

WrongColorMode(ColorModeColorMode)

Underlying data is in different color mode

TimestampMustBeHigherThanPrevious(i32i32)

Timestamp must be higher value than previous frame timestamp

TimestampMustBeEqualOrHigherThanPrevious(i32i32)

Timestamp must be higher or equal to the previous frame timestamp

EncoderAssmebleFailed

Encoder webp assembly failed

DimensionsMustbePositive

Supplied dimensions must be positive

NoFramesAdded

No frames have been supplied to encoder

ZeroSizeBuffer

Supplied zero-sized buffer where bytes where expected

InvalidEncodingConfig

Encoder config validation failed